@@ -47,8 +47,7 @@ typedef long Py_hash_t;
 
 #if PY_MAJOR_VERSION >= 3
 #define PY_STRING(x) PyUnicode_FromString(x)
-#define PY_STRING_TO_C(x) PyBytes_AsString(\
-                            PyUnicode_AsEncodedString(x, "utf-8", "strict"))
+#define PY_STRING_TO_C(x) PyUnicode_AsUTF8(x)
 #define PY_STRING_CHECK(x) PyUnicode_Check(x)
 #else
 #define PY_STRING(x) PyString_FromString(x)
@@ -425,7 +424,7 @@ PyObject* convert_object_to_python(
   {
     case OBJECT_TYPE_INTEGER:
       if (object->value.i != UNDEFINED)
-        result = Py_BuildValue("i", object->value.i);
+        result = Py_BuildValue("l", object->value.i);
       break;
 
     case OBJECT_TYPE_STRING:
@@ -1003,10 +1002,13 @@ int process_compile_externals(
     }
     else if (PY_STRING_CHECK(value))
     {
+      char* str = PY_STRING_TO_C(value);
+
+      if (str == NULL)
+        return ERROR_INVALID_ARGUMENT;
+
       result = yr_compiler_define_string_variable(
-          compiler,
-          identifier,
-          PY_STRING_TO_C(value));
+          compiler, identifier, str);
     }
     else
     {
@@ -1070,10 +1072,13 @@ int process_match_externals(
     }
     else if (PY_STRING_CHECK(value))
     {
+      char* str = PY_STRING_TO_C(value);
+
+      if (str == NULL)
+        return ERROR_INVALID_ARGUMENT;
+
       result = yr_rules_define_string_variable(
-          rules,
-          identifier,
-          PY_STRING_TO_C(value));
+          rules, identifier, str);
     }
     else
     {
@@ -2367,6 +2372,10 @@ MOD_INIT(yara)
   if (PyType_Ready(&Match_Type) < 0)
     return MOD_ERROR_VAL;
 
+  PyModule_AddObject(m, "Rule", (PyObject*) &Rule_Type);
+  PyModule_AddObject(m, "Rules", (PyObject*) &Rules_Type);
+  PyModule_AddObject(m, "Match",  (PyObject*) &Match_Type);
+
   PyModule_AddObject(m, "Error", YaraError);
   PyModule_AddObject(m, "SyntaxError", YaraSyntaxError);
   PyModule_AddObject(m, "TimeoutError", YaraTimeoutError);
